Crate gliclass

An inference engine for GLiClass models.

These language models are efficient for zero-shot topic classification or derivatives like sentiment analysis. They can also be used for efficient re-ranking.

GLiClass stands for “Generalist and Lightweight Model for Sequence Classification”, after an original work from Knowledgator, which was itself inspired by GLiNER.

Modules

input
Input steps of the pipeline
output
Output steps of the pipeline
params
GLiClass Parameters
pipeline
Orp pipeline for GLiClass classification
tokenizer
Wrapper around HuggingFace tokenizers
util

Structs

GLiClass
Convenience front-end for easy use with default runtime parameters (CPU). For more advanced use, see examples and the orp crate.