pub enum Labels {
Unique(Vec<String>),
PerText(Vec<Vec<String>>),
}Expand description
Labels, either a single list for all texts, or a list per text.
Variants
Unique(Vec<String>)
The same set of labels will be used for all the provided texts
PerText(Vec<Vec<String>>)
Specify a set of label per input text (in such case the texts and labels arrays must have the same length).
Implementations